/*******************************************************************************

Author : Mauro Laurenti
Version : 1.0
Created on Date : 19/06/2013
Last update     : 19/06/2013

CopyRight 2006-2013 all rights are reserved

********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author)
is intended for use solely and exclusively on Microchip PIC Microcontroller (registered mark).
The software is owned by the Author, and is protected under applicable copyright laws.
All rights are reserved.
Any use in violation of the foregoing restrictions may subject the
user to criminal sanctions under applicable laws (Italian or International ones), as well as to
civil liability for the breach of the terms and conditions of this license.
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the following
software doesn't aim to commercial use or monetary earning of any kind.

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT,
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************
PURPOSES
********************************************************

This file contains all the configuration words needed for the PIC18F14K50.
It can be easily adapted to other PICs according to the available configurations.

******  WARNING ******

The configurations must be changed to reflect the application needs!

//*****************************************************************************/


#ifndef PIC18F14K50_CONFIG_H
#define PIC18F14K50_CONFIG_H

#ifdef __XC8
#include <xc.h>
#endif

//******************************************************************************
// Register: CONFIG1L @ 0x300000
//******************************************************************************

// System Clock Postscaler Selection bits
//CLKDIV2	CPU System Clock divided by 2
//CLKDIV3	CPU System Clock divided by 3
//NOCLKDIV	No CPU System Clock divide
//CLKDIV4	CPU System Clock divided by 4
#pragma config CPUDIV =	NOCLKDIV


//USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)
//OFF	USB clock comes directly from the OSC1/OSC2 oscillator block; no divide
//ON	USB clock comes from the OSC1/OSC2 divided by 2
#pragma config USBDIV =	OFF


//******************************************************************************
// Register: CONFIG1H @ 0x300001
//******************************************************************************

//Internal/External Oscillator Switchover bit
//OFF	Oscillator Switchover mode disabled
//ON	Oscillator Switchover mode enabled
#pragma config IESO = OFF

//PLLEN =	4 X PLL Enable bit
//OFF	PLL is under software control
//ON	Oscillator multiplied by 4
#pragma config PLLEN = ON

//Oscillator Selection bits
//ECM	EC (medium)
//ERCCLKOUT	External RC oscillator, CLKOUT function on OSC2
//ECCLKOUTH	EC, CLKOUT function on OSC2 (high)
//XT	XT oscillator
//LP	LP oscillator
//ECCLKOUTL	EC, CLKOUT function on OSC2 (low)
//IRC	Internal RC oscillator
//ECCLKOUTM	EC, CLKOUT function on OSC2 (medium)
//IRCCLKOUT	Internal RC oscillator, CLKOUT function on OSC2
//ECH	EC (high)
//ECL	EC (low)
//ERC	External RC oscillator
//HS	HS oscillator
#pragma config FOSC =	HS

//Fail-Safe Clock Monitor Enable bit
//OFF	Fail-Safe Clock Monitor disabled
//ON	Fail-Safe Clock Monitor enabled

#pragma config FCMEN = OFF

//PCLKEN =	Primary Clock Enable bit
//OFF	Primary clock is under software control
//ON	Primary clock enabled

#pragma config PCLKEN = ON

//******************************************************************************
// Register: CONFIG2L @ 0x300002
//******************************************************************************


//Brown-out Reset Enable bits
//NOSLP	Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)
//OFF	Brown-out Reset disabled in hardware and software
//ON	Brown-out Reset enabled and controlled by software (SBOREN is enabled)
#pragma config BOREN = OFF

//Brown-out Reset Voltage bits
//19	VBOR set to 1.9 V nominal
//27	VBOR set to 2.7 V nominal
//22	VBOR set to 2.2 V nominal
//30	VBOR set to 3.0 V nominal
#pragma config BORV = 30

//PWRTEN =	Power-up Timer Enable bit
//OFF	PWRT disabled
//ON	PWRT enabled
#pragma config PWRTEN = OFF


//******************************************************************************
// Register: CCONFIG2H @ 0x300003
//******************************************************************************

//Watchdog Timer Postscale Select bits
//8	1:8
//1	1:1
//32768	1:32768
//1024	1:1024
//2	1:2
//32	1:32
//16	1:16
//16384	1:16384
//128	1:128
//4096	1:4096
//64	1:64
//8192	1:8192
//2048	1:2048
//512	1:512
//256	1:256
//4	1:4
#pragma config WDTPS = 32768

//Watchdog Timer Enable bit
//OFF	WDT is controlled by SWDTEN bit of the WDTCON register
//ON	WDT is always enabled. SWDTEN bit has no effect.
#pragma config WDTEN = OFF


//******************************************************************************
// Register: CONFIG3H @ 0x300005
//******************************************************************************


//MCLR Pin Enable bit
//OFF	RA3 input pin enabled; MCLR pin disabled
//ON	MCLR pin enabled; RA3 input pin disabled
#pragma config MCLRE = OFF

//HFOFST =	HFINTOSC Fast Start-up bit
//OFF	The system clock is held off until the HFINTOSC is stable.
//ON	HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.
#pragma config HFOFST = OFF

//******************************************************************************
// Register: CONFIG4L @ 0x300006
//******************************************************************************

//Background Debugger Enable bit
//OFF	Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins
//ON	Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug
#pragma config DEBUG = OFF

//Stack Full/Underflow Reset Enable bit
//OFF	Stack full/underflow will not cause Reset
//ON	Stack full/underflow will cause Reset
#pragma config STVREN =	ON

//Extended Instruction Set Enable bit
//OFF	Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
//ON	Instruction set extension and Indexed Addressing mode enabled
#pragma config XINST =	OFF

//BBSIZ =	Boot Block Size Select bit
//OFF	1kW boot block size
//ON	2kW boot block size
#pragma config BBSIZ =	OFF

//Single-Supply ICSP Enable bit
//OFF	Single-Supply ICSP disabled
//ON	Single-Supply ICSP enabled
#pragma config LVP = OFF


//******************************************************************************
// Register: CONFIG5L @ 0x300008
//******************************************************************************

//Code Protection bit
//OFF	Block 0 is not code-protected
//ON	Block 0 is code-protected
#pragma config CP0 = OFF


//Code Protection bit
//OFF	Block 1 is not code-protected
//ON	Block 1 is code-protected
#pragma config CP1 = OFF


//******************************************************************************
// Register: CONFIG5H @ 0x300009
//******************************************************************************

//Data EEPROM Code Protection bit
//OFF	Data EEPROM is not code-protected
//ON	Data EEPROM is code-protected
#pragma config CPD = OFF

//Boot Block Code Protection bit
//OFF	Boot block is not code-protected
//ON	Boot block is code-protected
#pragma config CPB = OFF


//******************************************************************************
// Register: CONFIG6L @ 0x30000A
//******************************************************************************

//Write Protection bit
//OFF	Block 0 is not write-protected
//ON	Block 0 is write-protected
#pragma config WRT0 = OFF

//Write Protection bit
//OFF	Block 1 is not write-protected
//ON	Block 1 is write-protected
#pragma config WRT1 = OFF


//******************************************************************************
// Register: CONFIG6H @ 0x30000B
//******************************************************************************

//Boot Block Write Protection bit
//OFF	Boot block is not write-protected
//ON	Boot block is write-protected
#pragma config WRTB = OFF

//Configuration Register Write Protection bit
//OFF	Configuration registers are not write-protected
//ON	Configuration registers are write-protected
#pragma config WRTC = OFF

//Data EEPROM Write Protection bit
//OFF	Data EEPROM is not write-protected
//ON	Data EEPROM is write-protected
#pragma config WRTD = OFF


//******************************************************************************
// Register: CONFIG7L @ 0x30000C
//******************************************************************************

//Table Read Protection bit
//OFF	Block 0 is not protected from table reads executed in other blocks
//ON	Block 0 is protected from table reads executed in other blocks
#pragma config EBTR0 = OFF

//Table Read Protection bit
//OFF	Block 1 is not protected from table reads executed in other blocks
//ON	Block 1 is protected from table reads executed in other blocks
#pragma config EBTR1 = OFF


//******************************************************************************
// Register: CONFIG7H @ 0x30000D
//******************************************************************************

//Boot Block Table Read Protection bit
//OFF	Boot block is not protected from table reads executed in other blocks
//ON	Boot block is protected from table reads executed in other blocks
#pragma config EBTRB = OFF
   

#endif