/*******************************************************************************

Author : Mauro Laurenti
Version : 1.0
Created on Date : 30/04/2013
Last update     : 30/04/2013

CopyRight 2006-2013 all rights are reserved


********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author) is intended for
use solely and exclusively on Microchip PIC Microcontroller (registered mark).
The software is owned by the Author, and is protected under applicable
copyright laws. All rights are reserved.
Any use in violation of the foregoing restrictions may subject the
user to criminal sanctions under applicable laws, as well as to civil liability
for the breach of the terms and conditions of this license.
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the
following software doesn't aim to commercial use or monetary earning of any kind.

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT,
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.


********************************************************
PURPOSES
********************************************************

This file contains all the configuration words needed for the PIC18F2331.
It can be easily adapted to other PICs according to the available configurations.

******  WARNING ******

The configurations must be changed to reflect the application needs!

//*****************************************************************************/


#ifndef PIC18F2331_CONFIG_H
#define PIC18F2331_CONFIG_H

#ifdef __XC8
#include <xc.h>
#endif


//******************************************************************************
// Register: CONFIG1H @ 0x300001
//******************************************************************************

//Internal External Oscillator Switchover bit
//OFF	Internal External Switchover mode disabled
//ON	Internal External Switchover mode enabled
#pragma config IESO = OFF

//Oscillator Selection bits
//RC	11XX External RC oscillator, CLKO function on RA6
//RC1	101X External RC oscillator, CLKO function on RA6
//IRCIO	Internal oscillator block, port function on RA6 and port function on RA7
//RCIO	External RC oscillator, port function on RA6
//RC2	External RC oscillator, CLKO function on RA6
//XT	XT oscillator
//LP	LP oscillator
//IRC	Internal oscillator block, CLKO function on RA6 and port function on RA7
//HSPLL	HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)
//ECIO	EC oscillator, port function on RA6
//EC	EC oscillator, CLKO function on RA6
//HS	HS oscillator
#pragma config OSC = IRC

//Fail-Safe Clock Monitor Enable bit
//OFF	Fail-Safe Clock Monitor disabled
//ON	Fail-Safe Clock Monitor enabled
#pragma config FCMEN =	OFF


//******************************************************************************
// Register: CONFIG2L @ 0x300002
//******************************************************************************

//Brown-out Reset Enable bits
//OFF	Brown-out Reset disabled
//ON	Brown-out Reset enabled
#pragma config BOREN =	ON

//Brown Out Reset Voltage bits
//42	VBOR set to 4.2V
//27	VBOR set to 2.7V
//45	VBOR set to 4.5V
#pragma config BORV = 42

//Power-up Timer Enable bit
//OFF	PWRT disabled
//ON	PWRT enabled
#pragma config PWRTEN = ON


//******************************************************************************
// Register: CONFIG2H @ 0x300003
//******************************************************************************

//Watchdog Timer Postscale Select bits
//8	1:8
//1	1:1
//32768	1:32768
//1024	1:1024
//2	1:2
//32	1:32
//16	1:16
//16384	1:16384
//128	1:128
//4096	1:4096
//64	1:64
//8192	1:8192
//2048	1:2048
//512	1:512
//256	1:256
//4	1:4
#pragma config WDPS = 1

//Watchdog Timer Enable bit
//OFF	WDT disabled (control is placed on the SWDTEN bit)
//ON	WDT enabled
//WINEN =	Watchdog Timer Window Enable bit
//OFF	WDT window disabled
//ON	WDT window enabledbled
#pragma config WDTEN =	OFF


//******************************************************************************
// Register: CONFIG3L @ 0x300004
//******************************************************************************

//Timer1 Oscillator MUX
//OFF	Standard (legacy) Timer1 oscillator operation
//ON	Low-power Timer1 operation when microcontroller is in Sleep mode
#pragma config T1OSCMX = OFF

//PWM output pins Reset state control
//OFF	PWM outputs disabled upon Reset (default)
//ON	PWM outputs drive active states upon Reset
#pragma config PWMPIN = OFF

//High-Side Transistors Polarity
//HIGH	PWM1, 3, 5 and 7 are active-high
//LOW	PWM1, 3, 5 and 7 are active-low
#pragma config HPOL = HIGH

//Low-Side Transistors Polarity
//HIGH	PWM0, 2, 4 and 6 are active-high
//LOW	PWM0, 2, 4 and 6 are active-low
#pragma config LPOL = LOW


//******************************************************************************
// Register: CONFIG3H @ 0x300005
//******************************************************************************

//MCLR Pin Enable bit
//OFF	Disabled
//ON	Enabled
#pragma config MCLRE = ON


//******************************************************************************
// Register: CONFIG4L @ 0x300006
//******************************************************************************

//Background Debugger Enable bit
//OFF	Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins
//ON	Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug
#pragma config DEBUG = ON

//Stack Full/Underflow Reset Enable bit
//OFF	Stack full/underflow will not cause Reset
//ON	Stack full/underflow will cause Reset
#pragma config STVREN = ON

//Low-Voltage ICSP Enable bit
//OFF	Low-voltage ICSP disabled
//ON	Low-voltage ICSP enabled
#pragma config LVP = OFF


//******************************************************************************
// Register: CONFIG5L @ 0x300008
//******************************************************************************

//Code Protection bit
//OFF	Block 0 (000200-000FFFh) not code-protected
//ON	Block 0 (000200-000FFFh) code-protected
#pragma config CP0 = OFF

//Code Protection bit
//OFF	Block 1 (001000-001FFF) not code-protected
//ON	Block 1 (001000-001FFF) code-protected
#pragma config CP1 = OFF


//******************************************************************************
// Register: CONFIG5H @ 0x300009
//******************************************************************************

//Data EEPROM Code Protection bit
//OFF	Data EEPROM not code-protected
//ON	Data EEPROM code-protected
#pragma config CPD = OFF

//Boot Block Code Protection bit
//OFF	Boot Block (000000-0001FFh) not code-protected
//ON	Boot Block (000000-0001FFh) code-protected
#pragma config CPB = OFF


//******************************************************************************
// Register: CONFIG6L @ 0x30000A
//******************************************************************************

//Write Protection bit
//OFF	Block 0 (000200-000FFFh) not write-protected
//ON	Block 0 (000200-000FFFh) write-protected
#pragma config WRT0 = OFF

//Write Protection bit
//OFF	Block 1 (001000-001FFF) not write-protected
//ON	Block 1 (001000-001FFF) write-protected
#pragma config WRT1 = OFF


//******************************************************************************
// Register: CONFIG6H @ 0x30000B
//******************************************************************************

//Boot Block Write Protection bit
//OFF	Boot Block (000000-0001FFh) not write-protected
//ON	Boot Block (000000-0001FFh) write-protected
#pragma config WRTB = OFF

//Configuration Register Write Protection bit
//OFF	Configuration registers (300000-3000FFh) not write-protected
//ON	Configuration registers (300000-3000FFh) write-protected
#pragma config WRTC = OFF

//Data EEPROM Write Protection bit
//OFF	Data EEPROM not write-protected
//ON	Data EEPROM write-protected
#pragma config WRTD = OFF


//******************************************************************************
// Register: CONFIG7L @ 0x30000C
//******************************************************************************

//Table Read Protection bit
//OFF	Block 0 (000200-000FFFh) not protected from table reads executed in other blocks
//ON	Block 0 (000200-000FFFh) protected from table reads executed in other blocks
#pragma config EBTR0 =	OFF

//Table Read Protection bit
//OFF	Block 1 (001000-001FFF) not protected from table reads executed in other blocks
//ON	Block 1 (001000-001FFF) protected from table reads executed in other blocks
#pragma config EBTR1 =	OFF


//******************************************************************************
// Register: CONFIG7H @ 0x30000D
//******************************************************************************
//Boot Block Table Read Protection bit
//OFF	Boot Block (000000-0001FFh) not protected from table reads executed in other blocks
//ON	Boot Block (000000-0001FFh) not protected from table reads executed in other blocks
//Register: IDLOC0 @ 0x200000
//Register: IDLOC1 @ 0x200001
//Register: IDLOC2 @ 0x200002
//Register: IDLOC3 @ 0x200003
//Register: IDLOC4 @ 0x200004
//Register: IDLOC5 @ 0x200005
//Register: IDLOC6 @ 0x200006
//Register: IDLOC7 @ 0x200007
#pragma config EBTRB =	OFF

#endif
