/*******************************************************************************

Author : Mauro Laurenti
Version : 1.2
 
Created on Date : 04/09/2006
Last update     : 30/04/2013

CopyRight 2006-2013 all rights are reserved

********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author) is intended for
use solely and exclusively on Microchip PIC Microcontroller (registered mark).
The software is owned by the Author, and is protected under applicable
copyright laws. All rights are reserved.
Any use in violation of the foregoing restrictions may subject the
user to criminal sanctions under applicable laws, as well as to civil liability
for the breach of the terms and conditions of this license.
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the
following software doesn't aim to commercial use or monetary earning of any kind.

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT,
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.


********************************************************
PURPOSES
********************************************************

These functions allow the user to read/write inside the eeprom 
that requires 2 address bytes such as the 24LC512.

********************************************************************************/

#ifndef I2C_EEPROM_H
#define I2C_EEPROM_H

#ifdef __XC8
    #include <xc.h>
        #ifndef _PIC18
            #error "The i2cEEPROM Library supports only PIC18 devices"
        #endif
#endif

#ifdef __18CXX
        #include <i2c.h>
#endif

#include <delay.h>


/**
 * This function writes a byte inside an I2C external EEPROM. 
 *
 * @param data Byte to write [min: 0, max: 255]
 *
 * @param address Address where the byte must be written [min: 0, max: depends on the EEPROM]
 *
 * @param control Is the address of the EEPROM set with the external address pins and the internal one. The bit R/'W set to 0. (i.g 0xA0)  
 *
 * @return status 1: The byte has been properly written
 *       		 -1: Bus Collision error
 *               -2: Not Ack error condition
 *               -3: Write collision
 *
 * @note This function only supports EEPROM which have two bytes for the address [min EEPROM is 25L32].
 */

signed char write_I2C_EEPROM( unsigned char control, unsigned int address, unsigned char data );


/**
 * This function writes a byte inside the EEPROM but it reads back the value to make sure that it has been properly
 * written. It's slower than the other one due to this feature.
 *
 * @param data Byte to write [min: 0, max: 255]
 *
 * @param address Address where the byte must be written [min: 0, max: depends on the EEPROM]
 *
 * @param control Is the address of the EEPROM set with the external address pins and the internal one. The bit R/'W set to 0. (i.g 0xA0)  
 *
 * @return status 1: The byte has been properly written
 *       		 -1: Bus Collision error
 *               -2: Not Ack error condition
 *               -3: Write collision
 *               -4: Readback error
 *
 * @note This function only supports EEPROM which have two bytes for the address [min EEPROM is 25L32].
 * @note To make this library works you need to include the delay library as well.
 */

signed char write_I2C_EEPROM_check( unsigned char control, unsigned int address, unsigned char data );


/**
 * This function reads a byte from an external I2C EEPROM.
 *
 *
 *
 * @param control Is the address of the EEPROM set with the external address pins and the internal one. The bit R/'W set to 0. (i.g 0xA0)  
 *
 * @param address Address where the byte must be read out [min: 0, max: depends on the EEPROM]
 *
 * @param *data Address of the variable where the read data will be written into.
 *
 * @return status 1: The byte has been properly written
 *       		 -1: Bus Collision error
 *               -2: Not Ack error condition
 *               -3: Write collision
 *
 * @note This function only supports EEPROM which have two bytes for the address [min EEPROM is 25L32].
 */

signed char read_I2C_EEPROM( unsigned char control, unsigned int address, unsigned char *data );

#endif