/*******************************************************************************

Author : Mauro Laurenti
Version : 1.3
Created on Date : 09/03/2012
Last update     : 04/10/2013

CopyRight 2006-2013 all rights are reserved

********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author) is intended for
use solely and exclusively on Microchip PIC Microcontroller (registered mark).
The software is owned by the Author, and is protected under applicable
copyright laws. All rights are reserved.
Any use in violation of the foregoing restrictions may subject the
user to criminal sanctions under applicable laws, as well as to civil liability
for the breach of the terms and conditions of this license.
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the
following software doesn't aim to commercial use or monetary earning of any kind.

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT,
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

*******************************************************************************/
									
#ifdef __XC8
    #include <xc.h>
    #include <stdlib.h>

    #ifndef _PIC18
        #error "The LCD_44780_I2C Library supports only PIC18 devices"
    #endif
#endif

#include "LCD_44780_I2C.h"
#include "PCF8574.h"
#include "PCF8574.c"
#include "delay.h"

unsigned char data_buffer = 0;
unsigned char PCF8574_address = 0;

//************************************************************
//                  enable_pulse_LCD  Implementation
//************************************************************
void enable_pulse_LCD (void) {
	data_buffer = data_buffer | LCD_E;
	PCF8574_write_data (PCF8574_address, data_buffer);
	delay_ms (1);
	data_buffer = data_buffer & ~LCD_E;
	PCF8574_write_data (PCF8574_address, data_buffer);
}


//************************************************************
//                  send_command_LCD  Implementation
//************************************************************
void send_command_LCD (unsigned char data) {


	//clear the lower nible
	data_buffer = data_buffer & 0b11100000; 

	//write the data within the buffer
	data_buffer = data_buffer | data;

	PCF8574_write_data (PCF8574_address, data_buffer);
	enable_pulse_LCD ();
}


//************************************************************
//                  home_LCD  Implementation
//************************************************************
void home_LCD(void) {
	
	send_command_LCD (0b00000000);
	send_command_LCD (0b00000010);
}


//************************************************************
//                  shift_LCD  Implementation
//************************************************************
void shift_LCD(unsigned char shift, unsigned char number_of_shift) {
	
	unsigned char i;
	
	for (i=0; i < number_of_shift; i++) {	
		send_command_LCD (0b00000001);
		send_command_LCD (0b00001000 | shift);
	}	
}


//************************************************************
//                  shift_cursor_LCD  Implementation
//************************************************************
void shift_cursor_LCD(unsigned char shift, unsigned char number_of_shift){
	
	unsigned char i;
	
	for (i=0; i < number_of_shift; i++) {
		send_command_LCD (0b00000001);
		send_command_LCD (0b00000000 | shift);
	} 		
}

//************************************************************
//                  goto_line_LCD  Implementation
//************************************************************
void goto_line_LCD (unsigned char line) {

switch(line) {

	case 1: send_command_LCD(0b00001000);
		send_command_LCD(0b00000000);
		break;

	case 2: send_command_LCD(0b00001100);
		send_command_LCD(0b00000000);
		break;

	case 3: send_command_LCD(0b00001001);
		send_command_LCD(0b00000100);
		break;

	case 4: send_command_LCD(0b00001101);
		send_command_LCD(0b00000100);
	}
}


//************************************************************
//                  goto_xy_LCD  Implementation
//************************************************************
void goto_xy_LCD (unsigned char x, unsigned char y){

    goto_line_LCD (y);
    shift_cursor_LCD (RIGHT, x-1);
}


//************************************************************
//                  write_char_LCD  Implementation
//************************************************************
void write_char_LCD (unsigned char value) {
	
	unsigned char preliminary_buffer;
	
	data_buffer = data_buffer | LCD_RS;
	PCF8574_write_data (PCF8574_address, data_buffer);

	// Splitting of the first nibble
	preliminary_buffer = (value & 0xF0) >> 4;	
					
	send_command_LCD (preliminary_buffer);
		
	// Splitting of the second nibble
	preliminary_buffer = (value & 0x0F);
			
	send_command_LCD (preliminary_buffer);
		
	data_buffer = data_buffer & ~LCD_RS;
	PCF8574_write_data (PCF8574_address, data_buffer);
}

//************************************************************
//                  write_message_LCD  Implementation
//************************************************************
#ifndef __XC8
void write_message_LCD(const rom unsigned char *buffer) {
#endif

#ifdef __XC8
void write_message_LCD(const unsigned char *buffer) {
#endif
	
	 // Write data to LCD up to null
    while(*buffer) {
	    
	    // Write character to LCD
	    write_char_LCD(*buffer);
	    // Increment buffer
	    buffer++;              
   }
}

//************************************************************
//                  write_string_LCD  Implementation
//************************************************************
void write_string_LCD(unsigned char *buffer) {
	
	// Write data to LCD up to null
	while(*buffer){
		
		// Write character to LCD
		write_char_LCD(*buffer);
		// Increment buffer
		buffer++;               
	}
}


//************************************************************
//                  write_integer_LCD  Implementation
//************************************************************
void write_integer_LCD(int value, unsigned char number_of_digits){
	
	// The array size is 5 plus end of string \0
	unsigned char convertedInt [6];
	
	// Index used to shift to the right the digit
	unsigned char index;
	
	// Integer is converted to string
        #ifndef __XC8
            itoa (value, (unsigned char*) convertedInt);
        #endif

        #ifdef __XC8
            itoa ((unsigned char*) convertedInt, value,10);
	#endif
	
	if (number_of_digits >0 ) {
		
		convertedInt[number_of_digits] = '\0';
		
		// Shift the digit to the right removing the empty one
		while (!(convertedInt[number_of_digits-1] <= '9' && convertedInt[number_of_digits-1] >= '0')) {
			
			for (index = number_of_digits-1; index > 0; index--){
				convertedInt[index] = convertedInt[index-1];
				convertedInt[index-1] = ' ';
			}							
		}	
	}

	write_string_LCD (convertedInt);
	
}	


//************************************************************
//                  clear_LCD  Implementation
//************************************************************
void clear_LCD (void){
	
	send_command_LCD (0b00000000);
	send_command_LCD (0b00000001);
}

//************************************************************
//                  cursor_LCD  Implementation
//************************************************************
void cursor_LCD(unsigned char active,unsigned char blinking) {
	
	SendCommand (0b00000000);	
	SendCommand (0b00001100 | active | blinking);								
}

//************************************************************
//                  backlight_LCD  Implementation
//************************************************************
void backlight_LCD(unsigned char active) {

	//Clear the LED bit
	data_buffer = data_buffer & ~TURN_ON_LED_LCD;

	//write the data within the buffer
	data_buffer = data_buffer | active;
	PCF8574_write_data (PCF8574_address, data_buffer);	
}

//************************************************************
//                  initialize_LCD  Implementation
//************************************************************
void  initialize_LCD(unsigned unsigned char quartz_frequency) {
	
	setQuartz (quartz_frequency);

	PCF8574_address = PCF8574_ADDRESS_H | (PCF8574_ADDRESS_L << 1);

	data_buffer = 0;
	PCF8574_write_data (PCF8574_address, data_buffer);	
	
	delay_ms (100);
	send_command_LCD (0b00000011);
	delay_ms (10);
	send_command_LCD (0b00000011);
	delay_ms (1);
	send_command_LCD (0b00000011);
		
	send_command_LCD (0b00000010);

	send_command_LCD (0b00000010);
	send_command_LCD (0b00000000);

	send_command_LCD (0b00000000);
	send_command_LCD (0b00001000);
        
        send_command_LCD (0b00000000);
	send_command_LCD (0b00000001);
        
        send_command_LCD (0b00000000);
	send_command_LCD (0b00000110);


	CursorLCD (TURN_OFF_CURSOR,BLINKING_OFF);
	ClearLCD ();	
}

