#include <xc.h>
#include "PIC18F4550_config.h"
#define _XTAL_FREQ 20000000
#include "delay.c"
#include <portb.h>
#include "PCF8563.c"
#define LCD_DEFAULT
#include "LCD_44780.c"


#define BT1 0b11100000
#define BT2 0b11010000
#define BT3 0b10110000
#define BT4 0b01110000


// Funzione per la gestione dell'interruzione
__interrupt(high_priority) void H_ISR(void) {

        unsigned char button;

	// Controllo che l'interrupt sia stato generato da PORTB
 	if (INTCONbits.RBIF == 1 ) {

	//pausa filtraggio spike
	delay_ms (30);  // non funziona
       // __delay_ms(30); // funziona

        button = PORTB;
	button = button & 0xF0;

	// Controllo del tasto premuto

	switch(button) {

  			case BT1 & BT3:
    				increment_minutes_RTCC ();
    				break;

  			case BT1 & BT4:
					increment_hours_RTCC ();
					break;

			case BT2:
					increment_years_RTCC ();
					break;

			case BT3:
					increment_months_RTCC ();
					break;

			case BT4:
					increment_days_RTCC ();
					break;

		 }

 	// Resetto il flag d'interrupt per permettere nuove interruzioni
 	INTCONbits.RBIF = 0;
 	}

}

/******************************************/
//           Programma Principale
/******************************************/

int main (void){

	// Variabile per salvare il dato di ritorno
	unsigned char data = 0;

	// Imposto PORTA tutti ingressi
	LATA = 0x00;
 	TRISA = 0xFF;

	// Imposto PORTB tutti ingressi
 	LATB = 0x00;
 	TRISB = 0xFF;

	// Imposto PORTC tutti ingressi, RC1 come output
 	LATC = 0x00;
 	TRISC = 0b11111100;

	// Imposto PORTD tutte uscite
 	LATD = 0x00;
 	TRISD = 0x00;

	// Imposto PORTE tutti ingressi
 	LATE = 0x00;
 	TRISE = 0xFF;


	// Inizializza il modulo I2C a 400KHz @20MHz
	OpenI2C(MASTER, SLEW_ON);
	SSPADD = 12;

 	OpenLCD (20);
 	BacklightLCD (TURN_ON_LED_LCD);

	// Inizializzo la data
	set_days_RTCC (0x30);
	set_months_RTCC (0x12);
	set_years_RTCC (0x08);

	// Inizializzo l'ora
	set_hours_RTCC (0x02);
	set_minutes_RTCC (0x56);
	set_seconds_RTCC (0x33);

	// Abilita i resistori di pull-up sulla PORTB
 	EnablePullups();

	// Abilito le interruzioni su PORTB
	INTCONbits.RBIE = 1;

	// Abilito modalita' compatibile (di default vale gia' 0)
	RCONbits.IPEN = 0;

	// Abilito l'interrupt globale
 	INTCONbits.GIE = 1;

 	// Abilito l'interrupt periferiche
 	INTCONbits.PEIE = 1 ;

	// Ciclo infinito
 	while (1) {

		WriteStringLCD ("Time :  ");

		WriteVarLCD (get_time_seconds_RTCC ());

                
		GotoLineLCD (2);
		WriteStringLCD ("Date :  ");

		WriteVarLCD (get_date_RTCC ());

		HomeLCD ();

	}
}
